@@ -89,3 +89,13 @@ then
     sed -i s/-site/-${SITE}/g ${PROJECT_DIR}/*_${SITE}.cfg
 fi
 
+# Indicate version of jmbo-skeleton used to create project
+VERSION=`sed "5q;d" setup.py | awk -F= '{print $2}'`
+echo "Changelog" > ${PROJECT_DIR}/CHANGELOG.rst
+echo "=========" >> ${PROJECT_DIR}/CHANGELOG.rst
+echo "" >> ${PROJECT_DIR}/CHANGELOG.rst
+echo "0.1" >> ${PROJECT_DIR}/CHANGELOG.rst
+echo "---" >> ${PROJECT_DIR}/CHANGELOG.rst
+echo "Project generated by jmbo-skeleton $VERSION" >> ${PROJECT_DIR}/CHANGELOG.rst 
+echo "" >> ${PROJECT_DIR}/CHANGELOG.rst
+
